@@ -1,4 +1,3 @@
-import sys
 import unittest
 from curtsies.formatstring import (
     FmtStr,
@@ -372,7 +371,7 @@ class TestUnicode(unittest.TestCase):
 
     def test_funny_chars(self) -> None:
         fmtstr("⁇", "blue")
-        str(Chunk("⁇", {"fg": "blue"}))
+        str(Chunk("⁇", {"fg": 34}))
         str(fmtstr("⁇", "blue"))
         self.assertTrue(True)
 
@@ -401,7 +400,6 @@ class TestUnicode(unittest.TestCase):
         # self.assertEqual(len(fmtstr('┌─')), 2)
 
     def test_len_of_unicode_in_fsarray(self) -> None:
-
         fsa = FSArray(3, 2)
         fsa.rows[0] = fsa.rows[0].setslice_with_length(0, 2, "┌─", 2)
         self.assertEqual(fsa.shape, (3, 2))
@@ -559,8 +557,7 @@ class TestFSArray(unittest.TestCase):
     def test_assignment_working(self) -> None:
         t = FSArray(10, 10)
         t[2, 2] = "a"
-        # TODO: is this supposed to check something?
-        t[2, 2] == "a"
+        self.assertEqual(t[2, 2], ["a"])
 
     def test_normalize_slice(self) -> None:
         class SliceBuilder:
